@@ -14,12 +14,14 @@ use Tie::Handle;
 
 use Moo;
 use Sub::HandlesVia;
-use Types::Standard qw(InstanceOf Str Int Bool HashRef ArrayRef ScalarRef CodeRef);
+use Types::Standard qw(
+    InstanceOf Str Int Bool HashRef ArrayRef ScalarRef CodeRef
+);
 use namespace::clean;
 
 has 'asp' => (
     is       => 'ro',
-    isa      => InstanceOf['Plasp'],
+    isa      => InstanceOf ['Plasp'],
     required => 1,
     weak_ref => 1,
 );
@@ -122,8 +124,9 @@ has 'CacheControl' => (
 
 before 'CacheControl' => sub {
     my $self = shift;
-    $self->asp->log->warn( 'Headers already written! Setting CacheControl has no effect!' )
-        if scalar( @_ ) && $self->_headers_written;
+    $self->asp->log->warn(
+        'Headers already written! Setting CacheControl has no effect!'
+    ) if scalar( @_ ) && $self->_headers_written;
 };
 
 =item $Response->{Charset}
@@ -144,8 +147,9 @@ has 'Charset' => (
 
 before 'Charset' => sub {
     my $self = shift;
-    $self->asp->log->warn( 'Headers already written! Setting Charset has no effect!' )
-        if scalar( @_ ) && $self->_headers_written;
+    $self->asp->log->warn(
+        'Headers already written! Setting Charset has no effect!'
+    ) if scalar( @_ ) && $self->_headers_written;
 };
 
 # This attribute has no effect
@@ -170,8 +174,9 @@ has 'ContentType' => (
 
 before 'ContentType' => sub {
     my $self = shift;
-    $self->asp->log->warn( 'Headers already written! Setting ContentType has no effect!' )
-        if scalar( @_ ) && $self->_headers_written;
+    $self->asp->log->warn(
+        'Headers already written! Setting ContentType has no effect!'
+    ) if scalar( @_ ) && $self->_headers_written;
 };
 
 =item $Response->{Expires}
@@ -190,8 +195,9 @@ has 'Expires' => (
 
 before 'Expires' => sub {
     my $self = shift;
-    $self->asp->log->warn( 'Headers already written! Setting Expires has no effect!' )
-        if scalar( @_ ) && $self->_headers_written;
+    $self->asp->log->warn(
+        'Headers already written! Setting Expires has no effect!'
+    ) if scalar( @_ ) && $self->_headers_written;
 };
 
 =item $Response->{ExpiresAbsolute}
@@ -203,15 +209,19 @@ e.g.
 =cut
 
 has 'ExpiresAbsolute' => (
-    is      => 'rw',
-    isa     => sub { die "$_[0] is not a supported date format!" if $_[0] && Str->check( $_[0] ) && ! str2time $_[0] },
+    is  => 'rw',
+    isa => sub {
+        die "$_[0] is not a supported date format!"
+            if $_[0] && Str->check( $_[0] ) && !str2time $_[0];
+    },
     default => '',
 );
 
 before 'ExpiresAbsolute' => sub {
     my $self = shift;
-    $self->asp->log->warn( 'Headers already written! Setting ExpiresAbsolute has no effect!' )
-        if scalar( @_ ) && $self->_headers_written;
+    $self->asp->log->warn(
+        'Headers already written! Setting ExpiresAbsolute has no effect!'
+    ) if scalar( @_ ) && $self->_headers_written;
 };
 
 =item $Response->{FormFill}
@@ -234,20 +244,12 @@ has 'FormFill' => (
 
 =item $Response->{IsClientConnected}
 
-1 if web client is connected, C<0> if not. This value starts set to 1, and will
-be updated whenever a C<< $Response->Flush() >> is called.
-
-As of Apache::ASP version 2.23 this value is updated correctly before
-F<global.asa> C<Script_OnStart> is called, so global script termination may be
-correctly handled during that event, which one might want to do with excessive
-user STOP/RELOADS when the web server is very busy.
-
-An API extension C<< $Response->IsClientConnected >> may be called for refreshed
-connection status without calling first a C<< $Response->Flush >>
+This is a carryover from Apache::ASP. However, Plack won't be able to detect
+this so we will assume that the client is always connected. This will just
+be true always for compatibility.
 
 =cut
 
-# This attribute has no effect
 has 'IsClientConnected' => (
     is      => 'ro',
     isa     => Bool,
@@ -276,8 +278,9 @@ has 'Status' => (
 
 before 'Status' => sub {
     my $self = shift;
-    $self->asp->log->warn( 'Headers already written! Setting Status has no effect!' )
-        if scalar( @_ ) && $self->_headers_written;
+    $self->asp->log->warn(
+        'Headers already written! Setting Status has no effect!'
+    ) if scalar( @_ ) && $self->_headers_written;
 };
 
 sub BUILD {
@@ -306,17 +309,17 @@ the main page is sent.
 =cut
 
 has 'Headers' => (
-    is      => 'rw',
-    isa     => ArrayRef
-    default => sub { [ ] },
+    is          => 'rw',
+    isa         => ArrayRef
+        default => sub { [] },
 );
 
 sub AddHeader {
     my ( $self, $name, $value ) = @_;
 
     $self->asp->log->warn( sprintf(
-        'Headers already written! Calling AddHeader with %s %s has no effect!',
-        $name, $value
+            'Headers already written! Calling AddHeader with %s %s has no effect!',
+            $name, $value
     ) ) if $self->_headers_written;
 
     # Don't duplicate these headers, set them for later
@@ -374,15 +377,19 @@ Erases buffered ASP output.
 sub Clear {
     my ( $self ) = @_;
 
-    # If a _content_writer is defined, then no need to keep track of flushed
-    # offset, simply clear Output buffer
     if ( $self->_content_writer ) {
+
+        # If a _content_writer is defined, then no need to keep track of flushed
+        # offset, simply clear Output buffer
         $self->clear_Output;
 
-    # Otherwise, keep track of last flushed offset and clear everything after
-    # that point.
     } else {
-        defined $self->Output && $self->Output( $self->OutputSubstr( 0, $self->_flushed_offset ) );
+
+        # Otherwise, keep track of last flushed offset and clear everything
+        # after that point.
+        defined $self->Output && $self->Output(
+            $self->OutputSubstr( 0, $self->_flushed_offset )
+        );
     }
 
     $self->{BinaryRef} = \( $self->{Output} );
@@ -470,8 +477,9 @@ has 'Cookies' => (
 
 before '_set_Cookie' => sub {
     my $self = shift;
-    $self->asp->log->warn( 'Headers already written! Setting Cookies has no effect!' )
-        if $self->_headers_written;
+    $self->asp->log->warn(
+        'Headers already written! Setting Cookies has no effect!'
+    ) if $self->_headers_written;
 };
 
 sub Cookies {
@@ -521,19 +529,24 @@ sub CookiesHeaders {
                 # This is really to support Apache::ASP's support for hashes
                 # as a cookie value
                 if ( $key =~ m/value/i && ref( $cookie->{$key} ) eq 'HASH' ) {
-                    $hash{-value} =
-                        [ map { "$_=" . $cookie->{$key}{$_} } keys %{ $cookie->{$key} } ];
+                    $hash{-value} = [
+                        map {
+                            "$_=" . $cookie->{$key}{$_}
+                        } keys %{ $cookie->{$key} }
+                    ];
                 } else {
 
-                    # Thankfully, don't need to make 'value' an arrayref for CGI::Simple::Cookie
-                    $hash{'-' . lc( $key )} = $cookie->{$key};
+                    # Thankfully, don't need to make 'value' an arrayref for
+                    # CGI::Simple::Cookie
+                    $hash{ '-' . lc( $key ) } = $cookie->{$key};
                 }
             }
         } else {
             $hash{-value} = $cookie;
         }
 
-        push @headers, 'Set-Cookie' => CGI::Simple::Cookie->new( %hash )->as_string;
+        push @headers,
+            'Set-Cookie' => CGI::Simple::Cookie->new( %hash )->as_string;
     }
 
     return \@headers;
@@ -598,7 +611,9 @@ sub End {
 # TODO will not implement
 sub ErrorDocument {
     my ( $self, $code, $uri ) = @_;
-    $self->asp->log->warn( "\$Response->ErrorDocument has not been implemented!" );
+    $self->asp->log->warn(
+        "\$Response->ErrorDocument has not been implemented!"
+    );
     return;
 }
 
@@ -649,7 +664,8 @@ sub Flush {
         # Set the Expires header from either Expires or ExpiresAbsolute
         # attribute
         if ( $self->Expires ) {
-            push @{ $self->Headers }, Expires => time2str( time + $self->Expires );
+            push @{ $self->Headers },
+                Expires => time2str( time + $self->Expires );
         } elsif ( $self->ExpiresAbsolute ) {
             push @{ $self->Headers }, Expires => $self->ExpiresAbsolute;
         }
@@ -713,16 +729,18 @@ sub Flush {
         $body = Encode::encode( 'UTF-8', $body );
     }
 
-    # In the case that streaming response is supported, a _content_writer
-    # should be defined. If so, use it to write out the body, then clear
-    # Output buffer.
     if ( $self->_content_writer ) {
+
+        # In the case that streaming response is supported, a _content_writer
+        # should be defined. If so, use it to write out the body, then clear
+        # Output buffer.
         $self->_content_writer->( $body );
         $self->Clear;
 
-    # If streaming response not supported, then keep track of a flushed offset
-    # and save the output up to that point.
     } else {
+
+        # If streaming response not supported, then keep track of a flushed
+        # offset and save the output up to that point.
         $self->_flushed_offset( $self->OutputLength );
     }
 
@@ -789,17 +807,19 @@ sub Include {
 
     my $compiled;
     if ( ref( $include ) && ref( $include ) eq 'SCALAR' ) {
-        my $scriptref = $include;
+        my $scriptref     = $include;
         my $parsed_object = $asp->parse( $scriptref );
         $compiled = {
             mtime => time(),
             perl  => $parsed_object->{data},
         };
         my $caller = [ caller( 1 ) ]->[3] || 'main';
-        my $id = join( '', '__ASP_', $caller, 'x', $asp->_compile_checksum );
+        my $id    = join( '', '__ASP_', $caller, 'x', $asp->_compile_checksum );
         my $subid = join( '', $asp->GlobalASA->package, '::', $id, 'xREF' );
         if ( $parsed_object->{is_perl}
-            && ( my $code = $asp->compile( $parsed_object->{data}, $subid ) ) ) {
+            && ( my $code = $asp->compile(
+                    $parsed_object->{data},
+                    $subid ) ) ) {
             $compiled->{is_perl} = 1;
             $compiled->{code}    = $code;
         } else {
@@ -822,28 +842,6 @@ sub Include {
     $asp->execute( $code, @args );
 }
 
-=item $Response->IsClientConnected()
-
-API Extension. C<1> for web client still connected, C<0> if disconnected which
-might happen if the user hits the stop button. The original API for this
-C<< $Response->{IsClientConnected} >> is only updated after a
-C<< $Response->Flush >> is called, so this method may be called for a refreshed
-status.
-
-Note C<< $Response->Flush >> calls C<< $Response->IsClientConnected >> to
-update C<< $Response->{IsClientConnected} >> so to use this you are going
-straight to the source! But if you are doing a loop like:
-
-  while(@data) {
-    $Response->End if ! $Response->{IsClientConnected};
-    my $row = shift @data;
-    %> <%= $row %> <%
-    $Response->Flush;
-  }
-
-Then its more efficient to use the member instead of the method since
-C<< $Response->Flush() >> has already updated that value for you.
-
 =item $Response->Redirect($url)
 
 Sends the client a command to go to a different url C<$url>. Script immediately
